/*
 * Code for an adafruit feather M4 express
 * What does it do? Nothing too fancy.
 * Basically, it reads the temperature from a NTC-resistor and sends it via I²C to some Slaves. 
 * Yes, I know... It's a highly complicated thermometer. Leave me alone. :-P
 * But! It also has a light sensor for turning off the Displays. How do you like me now?
 */
 
#include <Wire.h>
#include <Thermistor.h>
#include <NTC_Thermistor.h>
#include <SmoothThermistor.h>
#include <avr/dtostrf.h>

//First, some constants for calculating the temperature
#define SENSOR_PIN             A3 
#define REFERENCE_RESISTANCE   4630
#define NOMINAL_RESISTANCE     4700
#define NOMINAL_TEMPERATURE    25
#define B_VALUE                3977

//Smoothing factor of a temperature value.
#define SMOOTHING_FACTOR 5

Thermistor* thermistor = NULL;

// Light Sensor
int LIGHT_PIN = A2;
int LIGHT_VAL = 0;


void setup() {
  
  Serial.begin(115200);
  Wire.begin();

//Just used the code from the example. Why reinvent the wheel?
  Thermistor* originThermistor = new NTC_Thermistor(
    
    SENSOR_PIN,
    REFERENCE_RESISTANCE,
    NOMINAL_RESISTANCE,
    NOMINAL_TEMPERATURE,
    B_VALUE
  
  );
  
  thermistor = new SmoothThermistor(originThermistor, SMOOTHING_FACTOR);

}

void loop() {
  
  //Read temperature
  const double celsius = thermistor->readCelsius();
  
  //Read light
  LIGHT_VAL = analogRead(LIGHT_PIN);
  
  // Output of information
  Serial.print("Temperature: ");
  Serial.print(celsius);
  Serial.print(" C, ");
  Serial.print("Light: ");
  Serial.println(LIGHT_VAL);

  // So, this converts the double "celsius" into chars. 
  //There might be an easier way, but for know, it works. 
  char TEMP[5];
  dtostrf(celsius,2,2,TEMP);

  //From here on, I'm not content with this content, but it works as well.
  //If the lightsensor detects enough light (in this case, the brighter the light, the lower the readings from the AD-converter), 
  //the just converted temperature will be send via I²C.
  if(LIGHT_VAL < 990){
    
    Wire.beginTransmission(8);
    Wire.write(TEMP[0]); 
    Wire.write(TEMP[1]);
    Wire.endTransmission(); 
    
    Wire.beginTransmission(1);
    Wire.write(TEMP[3]); //Question: Why don't send TEMP[2]? Answer: It's the '.' char. But you probably knew that already.
    Wire.write(TEMP[4]);
    Wire.endTransmission(); 

  }

  //Is it to dark? Tell the Displays to turn off, by sending the char 'F'. 
  //There is a better way, but for a one-day-build it's okay.
  else if(LIGHT_VAL > 1010){

    Wire.beginTransmission(8);
    Wire.write("F"); 
    Wire.write("F");
    Wire.endTransmission();
    
    Wire.beginTransmission(1);
    Wire.write("F"); 
    Wire.write("F");
    Wire.endTransmission();
  
  }
  
  
  //I am terribly sorry for this. 
  //This should be turned into the millis() function.
  //But for testing purposes okay.
  delay(1000);

}
